@@ -35,6 +35,9 @@ use Locale::gettext;
 #Glib
 use Glib qw/TRUE FALSE/; 
 
+#File
+use File::Spec;
+
 #--------------------------------------
 
 ##################public subs##################
@@ -53,6 +56,7 @@ sub new {
 	$self->{_start_with}             	= undef;
 	$self->{_start_with_extra}			= undef;
 	$self->{_profile_to_start_with}  	= undef;
+	$self->{_export_filename}			= undef;
 
 	#Set LC_NUMERIC to C to prevent decimal commas (or anything else)
 	setlocale(LC_NUMERIC, "C");	
@@ -369,6 +373,19 @@ sub set_profile_to_start_with {
 	return $self->{_profile_to_start_with};
 }
 
+sub get_export_filename {
+	my $self = shift;
+	return $self->{_export_filename};
+}
+
+sub set_export_filename {
+	my $self = shift;
+	if (@_) {
+		$self->{_export_filename} = shift;
+	}
+	return $self->{_export_filename};
+}
+
 sub get_current_monitor {
 	my $self = shift;
 	my ( $window_at_pointer, $x, $y, $mask ) = Gtk2::Gdk->get_default_root_window->get_pointer;
