@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -49,6 +49,7 @@ sub new {
 	#import shutter dialogs
 	my $current_window = $self->{_window} || $self->{_common}->get_mainwindow;
 	$self->{_dialogs} = Shutter::App::SimpleDialogs->new( $current_window );
+	$self->{_lp} = Shutter::Pixbuf::Load->new( $self->{_common}, $current_window );
 
 	bless $self, $class;
 	return $self;
@@ -66,6 +67,18 @@ sub save_pixbuf_to_file {
 	#gettext variable
 	my $d = $self->{_common}->get_gettext;
 
+	#check if we need to rotate the image or set the exif data accordingly
+	my $option = $self->{_lp}->get_option($pixbuf, 'orientation');
+	$option = 1 unless defined $option;
+
+	#FIXME: NOT COVERED BY BINDINGS YET (we use Image::ExifTool instead)
+	#we rotate the pixbuf when saving to any other format than jpeg
+	unless ( $filetype eq 'jpeg' ) {
+		if($option != 1){
+			$pixbuf = $self->{_lp}->auto_rotate($pixbuf);
+		}
+	}
+
 	#we have two main ways of saving file
 	#when possible we try to use all supported formats of the gdk-pixbuf libs
 	#currently this is bmp, jpeg, png and ico (ico is not useful here)
@@ -87,6 +100,19 @@ sub save_pixbuf_to_file {
 		
 		eval{
 			$pixbuf->save( $filename, $filetype, quality => $quality );
+			
+			#FIXME: NOT COVERED BY BINDINGS YET (we use Image::ExifTool instead)
+			#~ $pixbuf->set_option( 'orientation' => $option );
+			if(my $exif = Shutter::App::Optional::Exif->new()){
+				#new Image::ExifTool instance 
+				my $exiftool = $exif->get_exiftool;
+				if($exiftool){
+					#Set a new value for a tag
+					$exiftool->SetNewValue('Orientation' => $option, Type => 'ValueConv');
+					#Write new meta information to a file
+					my $success = $exiftool->WriteInfo($filename);
+				}
+			}
 		};
 	} elsif ( $filetype eq 'png' ) {
 		
@@ -123,6 +149,19 @@ sub save_pixbuf_to_file {
 		undef $surface;
 		undef $cr;
 
+	} elsif ( $filetype eq 'ps' ) {
+		
+		#0.8? => 72 / 90 dpi		
+    	my $surface = Cairo::PsSurface->create($filename, $pixbuf->get_width * 0.8, $pixbuf->get_height * 0.8);
+    	my $cr = Cairo::Context->create($surface);
+		$cr->scale(0.8, 0.8);
+		Gtk2::Gdk::Cairo::Context::set_source_pixbuf( $cr, $pixbuf, 0, 0 );
+		$cr->paint;
+		$cr->show_page;
+				
+		undef $surface;
+		undef $cr;
+
 	} elsif ( $filetype eq 'svg' ) {	
 		
 		#0.8? => 72 / 90 dpi		
