@@ -33,6 +33,9 @@ use File::Temp qw/ tempfile tempdir /;
 #Glib
 use Glib qw/TRUE FALSE/; 
 
+#stringified perl data structures, suitable for both printing and eval
+use Data::Dumper;
+
 #--------------------------------------
 
 sub new {
@@ -351,46 +354,113 @@ sub get_pixbuf_from_drawable {
 	return ($pixbuf, $l_cropped, $r_cropped, $t_cropped, $b_cropped);
 }
 
-#code ported and partially borrowed from gnome-screenshot
+#code ported and partially borrowed from gnome-screenshot and Gimp
 sub include_cursor {
 
 	my ( $self, $xp, $yp, $widthp, $heightp, $gdk_window, $pixbuf ) = @_;
 
-	#~ require lib;
-	#~ import lib $self->{_sc}->get_root."/share/shutter/resources/modules";
-	#~ 
-	#~ require X11::Protocol;
-
-	#~ #X11 protocol and XSHAPE ext
-	#~ $self->{_x11} 			  = X11::Protocol->new( $ENV{ 'DISPLAY' } );
-	#~ $self->{_x11}{ext_xfixes} = $self->{_x11}->init_extension('XFIXES');
-
-	my $cursor = Gtk2::Gdk::Cursor->new( 'GDK_LEFT_PTR' );
-
-	my $cursor_pixbuf = $cursor->get_image;
+	require lib;
+	import lib $self->{_sc}->get_root."/share/shutter/resources/modules";
 	
-	#try to use default cursor if there was an error
-	unless ( $cursor_pixbuf) {
-		warn "WARNING: There was an error while getting the cursor image - using a default cursor\n";
-		my $icons_path = $self->{_sc}->get_root . "/share/shutter/resources/icons";
-		eval{
-			$cursor_pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($icons_path."/Normal.cur");
-		};
-		if($@){
-			warn "ERROR: There was an error while loading the default cursor: $@\n";
+	require X11::Protocol;
+
+	#X11 protocol and XFIXES ext
+	$self->{_x11} 			  = X11::Protocol->new( $ENV{ 'DISPLAY' } );
+	$self->{_x11}{ext_xfixes} = $self->{_x11}->init_extension('XFIXES');
+	
+	#pixbuf
+	my $cursor_pixbuf = undef;
+	
+	#Cursor position (root window coordinates)
+	my $cursor_pixbuf_xroot = undef;
+	my $cursor_pixbuf_yroot = undef;
+	
+	#The "hotspot" position
+	my $cursor_pixbuf_xhot = undef;
+	my $cursor_pixbuf_yhot = undef;
+
+	if($self->{_x11}{ext_xfixes}){
+		
+		my ($root_x, $root_y, $width, $height, $xhot, $yhot, $serial, $pixels) = $self->{_x11}->XFixesGetCursorImage;
+		
+		#packed data string
+		my $data;
+		my $pos = 0;
+		foreach my $y (0 .. $height-1) {
+			foreach my $x (0 .. $width-1) {		
+				my $argb = unpack 'L', substr($pixels,$pos,4);
+				my $a = ($argb >> 24) & 0xFF;
+				my $r = ($argb >> 16) & 0xFF;
+				my $g = ($argb >> 8)  & 0xFF;
+				my $b = ($argb >> 0)  & 0xFF;
+				$pos += 4;
+				
+				#~ print "r:$r,g:$g,b:$b,a:$a\n";
+				
+				$r = ($r * 255) / $a if($a);
+				$g = ($g * 255) / $a if($a);
+				$b = ($b * 255) / $a if($a);
+				
+				$data .= pack ('C*', $r, $g, $b, $a);
+			}
 		}
+
+		if($width > 1 && $height > 1){
+			$cursor_pixbuf = Gtk2::Gdk::Pixbuf->new_from_data($data,'rgb',1,8,$width,$height-1,4*$width);
+
+			$cursor_pixbuf_xhot = $xhot;
+			$cursor_pixbuf_yhot = $yhot;
+
+			$cursor_pixbuf_xroot = $root_x;
+			$cursor_pixbuf_yroot = $root_y;
+		}else{
+			warn "WARNING: There was an error while getting the cursor image (XFIXESGetCursorImage)\n";
+		}
+		
+	}else{
+
+		warn "WARNING: XFIXES extension not found - using a default cursor image\n";
+
+		my ( $window_at_pointer, $root_x, $root_y, $mask ) = $gdk_window->get_pointer;
+
+		my $cursor = Gtk2::Gdk::Cursor->new( 'GDK_LEFT_PTR' );
+		$cursor_pixbuf = $cursor->get_image;
+	
+		#try to use default cursor if there was an error
+		unless ( $cursor_pixbuf) {
+			warn "WARNING: There was an error while getting the default cursor image - using one of our image files\n";
+			my $icons_path = $self->{_sc}->get_root . "/share/shutter/resources/icons";
+			eval{
+				$cursor_pixbuf = Gtk2::Gdk::Pixbuf->new_from_file($icons_path."/Normal.cur");
+			};
+			if($@){
+				warn "ERROR: There was an error while loading the image file: $@\n";
+			}
+		}
+		
+		if( $cursor_pixbuf ){
+			$cursor_pixbuf_xhot = $cursor_pixbuf->get_option('x_hot');
+			$cursor_pixbuf_yhot = $cursor_pixbuf->get_option('y_hot');
+			
+			$cursor_pixbuf_xroot = $root_x;
+			$cursor_pixbuf_yroot = $root_y;
+		}
+		
 	}
 	
 	if ( $cursor_pixbuf ) {
-		my ( $window_at_pointer, $x, $y, $mask ) = $gdk_window->get_pointer;
+	
+		#x,y pos (cursor)
+		my $x = $cursor_pixbuf_xroot;
+		my $y = $cursor_pixbuf_yroot;
 	
 		#screenshot dimensions saved in a rect (global x, y)
 		my $scshot  = Gtk2::Gdk::Rectangle->new( $xp, $yp, $widthp, $heightp );
 		
 		#see 'man xcursor' for a detailed description
 		#of these values
-		my $xhot = $cursor_pixbuf->get_option('x_hot');
-		my $yhot = $cursor_pixbuf->get_option('y_hot');
+		my $xhot = $cursor_pixbuf_xhot;
+		my $yhot = $cursor_pixbuf_yhot;
 
 		#cursor dimensions (global x, y and width and height of the pixbuf)
 		my $cursor = Gtk2::Gdk::Rectangle->new( $x, $y, $cursor_pixbuf->get_width, $cursor_pixbuf->get_height );
@@ -415,12 +485,13 @@ sub include_cursor {
 									   $pixbuf, 
 									   $dest_x,
 									   $dest_y, 
-									   $cursor->width + $xhot,
-									   $cursor->height + $yhot, 
+									   $cursor->width,
+									   $cursor->height, 
 									   $x - $xp - $xhot,
 									   $y - $yp - $yhot, 
 									   1.0, 1.0, 'bilinear', 255
 									 );
+									 
 		}
 	}
 
