@@ -1,6 +1,6 @@
 ###################################################
 #
-#  Copyright (C) 2008, 2009, 2010 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
+#  Copyright (C) 2008-2011 Mario Kemper <mario.kemper@googlemail.com> and Shutter Team
 #
 #  This file is part of Shutter.
 #
@@ -120,10 +120,11 @@ sub select_advanced {
 
 		#obtain current colors and font_desc from the main window
 		my $style 		= $self->{_sc}->get_mainwindow->get_style;
-		my $sel_bg 		= $style->bg('selected');
+		#~ my $sel_bg 		= $style->bg('selected');
+		my $sel_bg 		= Gtk2::Gdk::Color->parse('#131313');
 		my $sel_tx 		= $style->text('selected');
 		my $font_fam 	= $style->font_desc->get_family;
-		my $font_size 	= $style->font_desc->get_size;
+		my $font_size 	= $style->font_desc->get_size / Gtk2::Pango->scale;
 		
 		#create cairo context und layout
 		my $surface = Cairo::ImageSurface->create( 'argb32', $self->{_root}->{w}, $self->{_root}->{h} );
@@ -139,29 +140,34 @@ sub select_advanced {
 		$layout->set_wrap('word');
 		
 		#determine font-size
-		my $size = int( $mon1->width * 0.014 );
-		my $size2 = int( $mon1->width * 0.007 );
+		my $size1 = int ($font_size * 2.0);
+		my $size2 = int ($font_size * 1.5);
+		my $size3 = int ($font_size * 1.0);
 		
-		my $text
-			= $d->get(
-			"Draw a rectangular area using the mouse. To take a screenshot, press the Enter key. Press Esc to quit."
-			);
+		my $text1 = 
+			$d->get("Draw a rectangular area using the mouse.");
+		
+		my $text2 =
+			$d->get("To take a screenshot, press the Enter key. Press Esc to quit.");
 
-		my $sec_text
-			= $d->get(
-			"shift/right-click = selection dialog on/off\nctrl + scrollwheel = zoom in/out\t\tspace = zoom window on/off\ncursor keys + alt = move selection\t\tcursor keys + ctrl = resize selection"
-			);
+		my $text3 = 
+			$d->get("<b>shift/right-click</b> → selection dialog on/off")."\n".
+			$d->get("<b>ctrl + scrollwheel</b> → zoom in/out")."\n".
+			$d->get("<b>space</b> → zoom window on/off")."\n".
+			$d->get("<b>cursor keys</b> → move cursor")."\n".
+			$d->get("<b>cursor keys + alt</b> → move selection")."\n".
+			$d->get("<b>cursor keys + ctrl</b> → resize selection");
 
 		#use this one for white font-color	
-		$layout->set_markup("<span font_desc=\"$font_fam $size\" foreground=\"#FFFFFF\">$text</span>\n\n<span font_desc=\"$font_fam $size2\" weight=\"bold\" foreground=\"#FFFFFF\">$sec_text</span>");
+		$layout->set_markup("<span font_desc=\"$font_fam $size1\" foreground=\"#FFFFFF\">$text1</span>\n<span font_desc=\"$font_fam $size2\" foreground=\"#FFFFFF\">$text2</span>\n\n<span font_desc=\"$font_fam $size3\" foreground=\"#FFFFFF\">$text3</span>");
 		
 		#draw the rectangle
 		$cr->set_source_rgba( $sel_bg->red / 257 / 255, $sel_bg->green / 257 / 255, $sel_bg->blue / 257 / 255, 0.85 );
 
 		my ( $lw, $lh ) = $layout->get_pixel_size;
 
-		my $w = $lw + $size * 2;
-		my $h = $lh + $size * 2;
+		my $w = $lw + $size1 * 2;
+		my $h = $lh + $size1 * 2;
 		my $x = int( ( $mon1->width - $w ) / 2 ) + $mon1->x;
 		my $y = int( ( $mon1->height - $h ) / 2 ) + $mon1->y;
 		my $r = 20;
@@ -177,7 +183,7 @@ sub select_advanced {
 		$cr->curve_to( $x, $y, $x, $y, $x + $r, $y );
 		$cr->fill;
 
-		$cr->move_to( $x + $size, $y + $size );
+		$cr->move_to( $x + $size1, $y + $size1 );
 		
 		#draw the pango layout
 		Gtk2::Pango::Cairo::show_layout( $cr, $layout );
@@ -286,13 +292,21 @@ sub select_advanced {
 
 	#window that contains the imageview widget
 	$self->{_select_window} = Gtk2::Window->new('popup');
+	$self->{_select_window}->set_type_hint('splashscreen');
+	$self->{_select_window}->set_has_frame(FALSE);
+	$self->{_select_window}->can_focus(TRUE);
+	$self->{_select_window}->set_accept_focus(TRUE);
+	$self->{_select_window}->set_modal(TRUE);
 	$self->{_select_window}->set_decorated(FALSE);
 	$self->{_select_window}->set_skip_taskbar_hint(TRUE);
 	$self->{_select_window}->set_skip_pager_hint(TRUE);
 	$self->{_select_window}->set_keep_above(TRUE);
 	$self->{_select_window}->add($self->{_view});
+	$self->{_select_window}->set_default_size($self->{_root}->{w}, $self->{_root}->{h});
+	$self->{_select_window}->resize($self->{_root}->{w}, $self->{_root}->{h});
+	$self->{_select_window}->move($self->{_root}->{x}, $self->{_root}->{y});	
 	$self->{_select_window}->show_all;
-	$self->{_select_window}->window->set_override_redirect(TRUE);
+	$self->{_select_window}->present;
 
 	#init state flags
 	if($self->{_show_help}) {
@@ -349,20 +363,6 @@ sub select_advanced {
 		}
 	);
 
-	#see docs
-	#http://library.gnome.org/devel/gtk/stable/GtkWindow.html
-	#asks the window manager to move window to the given position.
-	#Window managers are free to ignore this;
-	#most window managers ignore requests for initial window positions
-	#(instead using a user-defined placement algorithm) and
-	#honor requests after the window has already been shown.
-	$self->{_select_window}->window->move_resize(
-		$self->{_root}->{x},
-		$self->{_root}->{y},
-		$self->{_root}->{w},
-		$self->{_root}->{h}
-	);
-
 	#set initial size
 	if($self->{_init_w} && $self->{_init_h}){
 		$self->{_selector}->set_selection(
@@ -370,52 +370,68 @@ sub select_advanced {
 		);			
 	}
 	
-	#event-handling	
-	$self->{_select_window}->signal_connect('event' =>
+	#event-handling
+	#we simulate a 2button-press here	
+	$self->{_view_button_handler} = $self->{_view}->signal_connect('button-press-event' =>
+		sub {
+			my ( $view, $event ) = @_;
+			return FALSE unless defined $event;
+			
+			my $s = $self->{_selector}->get_selection;
+			
+			if ($event->button == 1) {
+			
+				unless(defined $self->{_dclick}){
+
+					$self->{_dclick} = $event->time;
+					return FALSE;	
+
+				}else{
+
+					if($event->time - $self->{_dclick} <= 500){
+					
+						$self->{_select_window}->hide;
+						$self->{_zoom_window}->hide;
+						$self->{_prop_window}->hide;
+						
+						#A short timeout to give the server a chance to
+						#redraw the area
+						Glib::Timeout->add ($self->{_hide_time}, sub{		
+							Gtk2->main_quit;
+							return FALSE;	
+						});	
+						Gtk2->main();
+
+						$output = $self->take_screenshot($s, $clean_pixbuf);
+						$self->quit;
+					
+					}else{
+						
+						$self->{_dclick} = $event->time;
+						return FALSE;
+					
+					}					
+				}
+
+			}
+		}
+	);
+
+	#event-handling
+	#all other events
+	$self->{_view_event_handler} = $self->{_view}->signal_connect('event' =>
 		sub {
 			my ( $window, $event ) = @_;
-			return 0 unless defined $event;
+			return FALSE unless defined $event;
 
 			my $s = $self->{_selector}->get_selection;				
 			
 			#~ print $event->type, "\n";
 							
 			#handle button-release event
-			#we simulate a 2button-press here
-			if ( $event->type eq 'button-release') {		
+			if ( $event->type eq 'button-release' ) {		
 				
-				#left mouse button
-				if($event->button == 1){
-					
-					unless(defined $self->{_dclick}){
-	
-						$self->{_dclick} = $event->time;		
-	
-					}else{
-	
-						if($event->time - $self->{_dclick} <= 500){
-						
-							$self->{_select_window}->hide;
-							$self->{_zoom_window}->hide;
-							$self->{_prop_window}->hide;
-							
-							#A short timeout to give the server a chance to
-							#redraw the area that was obscured by our dialog.
-							Glib::Timeout->add ($self->{_hide_time}, sub{
-								$output = $self->take_screenshot($s, $clean_pixbuf);
-								$self->quit;
-								return FALSE;	
-							});
-						
-						}else{
-							
-							$self->{_dclick} = $event->time;
-						
-						}					
-	
-					}
-					
-				}elsif($event->button == 3){
+				if($event->button == 3){
 					if($self->{_prop_active}){
 						Gtk2::Gdk->keyboard_ungrab( Gtk2->get_current_event_time );
 						$self->{_prop_window}->hide_all;
@@ -534,7 +550,7 @@ sub select_advanced {
 				my ( $window_at_pointer, $x, $y, $mask ) = $self->{_root}->get_pointer;
 
 				#toggle zoom window
-				if ( $event->keyval == $Gtk2::Gdk::Keysyms{space} ) {
+				if ( $event->keyval == Gtk2::Gdk->keyval_from_name('space') ) {
 					
 					if ($self->{_zoom_active}){
 						$self->{_zoom_window}->hide_all;
@@ -545,7 +561,7 @@ sub select_advanced {
 					} 
 
 				#toggle prop dialog				
-				}elsif ( $event->keyval == $Gtk2::Gdk::Keysyms{Shift_L} || $event->keyval == $Gtk2::Gdk::Keysyms{Shift_R} ) {
+				}elsif ( $event->keyval == Gtk2::Gdk->keyval_from_name('Shift_L') || $event->keyval == Gtk2::Gdk->keyval_from_name('Shift_R') ) {
 					
 					if($self->{_prop_active}){
 						Gtk2::Gdk->keyboard_ungrab( Gtk2->get_current_event_time );
@@ -562,12 +578,12 @@ sub select_advanced {
 					}
 						
 				#abort screenshot				
-				}elsif ( $event->keyval == $Gtk2::Gdk::Keysyms{Escape} ) {
+				}elsif ( $event->keyval == Gtk2::Gdk->keyval_from_name('Escape') ) {
 											
 					$self->quit;
 				
 				#move / resize selector
-				} elsif ( $event->keyval == $Gtk2::Gdk::Keysyms{Up} ) {
+				} elsif ( $event->keyval == Gtk2::Gdk->keyval_from_name('Up') ) {
 					
 					if ($event->state >= 'control-mask' && $s){
 						$s->height($s->height-1);
@@ -581,7 +597,7 @@ sub select_advanced {
 						$self->{_gdk_display}->warp_pointer($self->{_gdk_screen}, $x, $y-1);
 					}
 					
-				} elsif ( $event->keyval == $Gtk2::Gdk::Keysyms{Down} ) {
+				} elsif ( $event->keyval == Gtk2::Gdk->keyval_from_name('Down') ) {
 
 					if ($event->state >= 'control-mask' && $s){
 						$s->height($s->height+1);
@@ -600,7 +616,7 @@ sub select_advanced {
 						$self->{_gdk_display}->warp_pointer($self->{_gdk_screen}, $x, $y+1);
 					}
 					
-				} elsif ( $event->keyval == $Gtk2::Gdk::Keysyms{Left} ) {
+				} elsif ( $event->keyval == Gtk2::Gdk->keyval_from_name('Left') ) {
 
 					if ($event->state >= 'control-mask' && $s){
 						$s->width($s->width-1);
@@ -614,7 +630,7 @@ sub select_advanced {
 						$self->{_gdk_display}->warp_pointer($self->{_gdk_screen}, $x-1, $y);
 					}
 					
-				} elsif ( $event->keyval == $Gtk2::Gdk::Keysyms{Right} ) {	
+				} elsif ( $event->keyval == Gtk2::Gdk->keyval_from_name('Right') ) {	
 
 					if ($event->state >= 'control-mask' && $s){
 						$s->width($s->width+1);
@@ -635,9 +651,9 @@ sub select_advanced {
 				
 				#zoom in
 				} elsif ( 
-					$event->keyval == $Gtk2::Gdk::Keysyms{KP_Add} ||
-					$event->keyval == $Gtk2::Gdk::Keysyms{plus} ||
-					$event->keyval == $Gtk2::Gdk::Keysyms{equal}		
+					$event->keyval == Gtk2::Gdk->keyval_from_name('KP_Add') ||
+					$event->keyval == Gtk2::Gdk->keyval_from_name('plus') ||
+					$event->keyval == Gtk2::Gdk->keyval_from_name('equal')		
 				) {	
 
 					if ($event->state >= 'control-mask'){
@@ -646,8 +662,8 @@ sub select_advanced {
 
 				#zoom out
 				} elsif ( 
-					$event->keyval == $Gtk2::Gdk::Keysyms{KP_Subtract} ||
-					$event->keyval == $Gtk2::Gdk::Keysyms{minus}		
+					$event->keyval == Gtk2::Gdk->keyval_from_name('KP_Subtract')||
+					$event->keyval == Gtk2::Gdk->keyval_from_name('minus')
 				) {	
 
 					if ($event->state >= 'control-mask'){
@@ -656,7 +672,7 @@ sub select_advanced {
 
 				#zoom normal
 				} elsif ( 
-					$event->keyval == $Gtk2::Gdk::Keysyms{0}	
+					$event->keyval == Gtk2::Gdk->keyval_from_name('0')
 				) {	
 
 					if ($event->state >= 'control-mask'){
@@ -664,29 +680,31 @@ sub select_advanced {
 					}
 												
 				#take screenshot
-				} elsif ( $event->keyval == $Gtk2::Gdk::Keysyms{Return} || $event->keyval == $Gtk2::Gdk::Keysyms{KP_Enter}) {
+				} elsif ( $event->keyval == Gtk2::Gdk->keyval_from_name('Return') || $event->keyval == Gtk2::Gdk->keyval_from_name('KP_Enter')) {
 					
 					$self->{_select_window}->hide;
 					$self->{_zoom_window}->hide;
 					$self->{_prop_window}->hide;
 					
 					#A short timeout to give the server a chance to
-					#redraw the area that was obscured by our dialog.
-					Glib::Timeout->add ($self->{_hide_time}, sub{
-						$output = $self->take_screenshot($s, $clean_pixbuf);
-						$self->quit;
+					#redraw the area
+					Glib::Timeout->add ($self->{_hide_time}, sub{		
+						Gtk2->main_quit;
 						return FALSE;	
-					});		
+					});	
+					Gtk2->main();
+					
+					$output = $self->take_screenshot($s, $clean_pixbuf);
+					$self->quit;
 									
 				}
 			}	
 		}
 	);
-
-	#finally focus it
+	
 	my $status = Gtk2::Gdk->keyboard_grab( $self->{_select_window}->window, 0, Gtk2->get_current_event_time );
 		
-	if($status eq 'success'){	
+	#~ if($status eq 'success'){	
 		if($self->{_zoom_active}){
 			$self->{_zoom_window}->show_all;
 			$self->{_zoom_window}->window->set_override_redirect(TRUE);
@@ -694,12 +712,10 @@ sub select_advanced {
 			$self->{_zoom_window}->window->raise;
 		}
 		Gtk2->main();
-	}else{
-		$output = 1;
-		$self->{_select_window}->destroy;
-		$self->{_zoom_window}->destroy;
-		$self->{_prop_window}->destroy;
-	}
+	#~ }else{
+		#~ $output = 1;
+		#~ $self->clean;
+	#~ }
 
 	return $output;
 }
@@ -891,8 +907,9 @@ sub select_dialog {
 	$hw_hbox->pack_start( $heightw_label, FALSE, FALSE, 5 );
 	$hw_hbox->pack_start( $self->{_height_spin_w}, FALSE, FALSE, 5 );
 
-	my $prop_dialog = Gtk2::Window->new('popup');
-	$prop_dialog->set_decorated(TRUE);
+	my $prop_dialog = Gtk2::Window->new('toplevel');
+	$prop_dialog->set_modal(TRUE);
+	$prop_dialog->set_decorated(FALSE);
 	$prop_dialog->set_skip_taskbar_hint(TRUE);
 	$prop_dialog->set_skip_pager_hint(TRUE);	
 	$prop_dialog->set_keep_above(TRUE);
@@ -904,7 +921,7 @@ sub select_dialog {
 		my $event  = shift;
 		
 		#toggle zoom window
-		if ( $event->keyval == $Gtk2::Gdk::Keysyms{space} ) {
+		if ( $event->keyval == Gtk2::Gdk->keyval_from_name('Space') ) {
 			
 			if ($self->{_zoom_active}){
 				$self->{_zoom_window}->hide_all;
@@ -915,7 +932,7 @@ sub select_dialog {
 			} 
 	
 		#toggle prop dialog				
-		}elsif ( $event->keyval == $Gtk2::Gdk::Keysyms{Shift_L} || $event->keyval == $Gtk2::Gdk::Keysyms{Shift_R} ) {
+		}elsif ( $event->keyval == Gtk2::Gdk->keyval_from_name('Shift_L') || $event->keyval == Gtk2::Gdk->keyval_from_name('Shift_R') ) {
 			
 			if($self->{_prop_active}){
 				Gtk2::Gdk->keyboard_ungrab( Gtk2->get_current_event_time );
@@ -932,7 +949,7 @@ sub select_dialog {
 			}
 				
 		#abort screenshot				
-		}elsif ( $event->keyval == $Gtk2::Gdk::Keysyms{Escape} ) {
+		}elsif ( $event->keyval == Gtk2::Gdk->keyval_from_name('Escape') ) {
 									
 			$self->quit;
 		
@@ -1057,12 +1074,19 @@ sub quit {
 	my $self = shift;
 	
 	$self->ungrab_pointer_and_keyboard( FALSE, FALSE, TRUE );
+	$self->clean;
+}
+
+sub clean {
+	my $self = shift;
+	
 	$self->{_selector}->signal_handler_disconnect ($self->{_selector_handler});
 	$self->{_view}->signal_handler_disconnect ($self->{_view_zoom_handler});
+	$self->{_view}->signal_handler_disconnect ($self->{_view_button_handler});
+	$self->{_view}->signal_handler_disconnect ($self->{_view_event_handler});
 	$self->{_select_window}->destroy;
 	$self->{_zoom_window}->destroy;
 	$self->{_prop_window}->destroy;
-	
 }
 
 1;
