@@ -81,16 +81,18 @@ sub new {
 			$self->{_highlighter}->set_colormap($self->{_main_gtk_window}->get_screen->get_rgba_colormap);
 		}
 
-		$self->{_highlighter}->set_type_hint('splashscreen');
-		$self->{_highlighter}->set_has_frame(FALSE);
-		$self->{_highlighter}->can_focus(TRUE);
-		$self->{_highlighter}->set_accept_focus(TRUE);
-		$self->{_highlighter}->set_modal(TRUE);
+		#~ $self->{_highlighter}->set_type_hint('splashscreen');
+		#~ $self->{_highlighter}->set_has_frame(FALSE);
+		#~ $self->{_highlighter}->can_focus(TRUE);
+		#~ $self->{_highlighter}->set_accept_focus(TRUE);
+		#~ $self->{_highlighter}->set_modal(TRUE);
+		
 	    $self->{_highlighter}->set_app_paintable(TRUE);
 	    $self->{_highlighter}->set_decorated(FALSE);
 		$self->{_highlighter}->set_skip_taskbar_hint(TRUE);
 		$self->{_highlighter}->set_skip_pager_hint(TRUE);	    
 	    $self->{_highlighter}->set_keep_above(TRUE);
+		$self->{_highlighter}->set_accept_focus(FALSE);
 
 		#obtain current colors and font_desc from the main window
 	    my $style 		= $self->{_main_gtk_window}->get_style;
@@ -106,6 +108,9 @@ sub new {
 
 			return FALSE unless $self->{_highlighter}->window;
 
+			#Place window and resize it
+			$self->{_highlighter}->window->move_resize($self->{_c}{'cw'}{'x'}-3, $self->{_c}{'cw'}{'y'}-3 ,$self->{_c}{'cw'}{'width'}+6, $self->{_c}{'cw'}{'height'}+6);			
+			
 			print $self->{_c}{'cw'}{'window'}->get_name, "\n" if $self->{_sc}->get_debug; 
 
 			my $text = Glib::Markup::escape_text ($self->{_c}{'cw'}{'window'}->get_name);
@@ -298,10 +303,14 @@ sub get_shape {
 
 	print "Calculating window shape\n" if $self->{_sc}->get_debug;
 
-	my ($ordering, @r) = $self->{_x11}->ShapeGetRectangles($self->find_wm_window($xid), 'Bounding');
+	#check if extenstion is available and use it
+	my ($ordering, @r) = (undef, undef);
+	if($self->{_x11}{ext_shape}){
+		($ordering, @r) = $self->{_x11}->ShapeGetRectangles($self->find_wm_window($xid), 'Bounding');
+	}
 	
 	my $manually_shaped = FALSE;
-	#create shape manually when option is set
+	#create shape manually when option is set and the shape was not detected automatically
 	if (scalar @r <= 1 && defined $self->{_auto_shape} && $self->{_auto_shape}){
 		
 		my $shf = Shutter::App::HelperFunctions->new( $self->{_sc} );
@@ -475,22 +484,12 @@ sub get_window_size {
 
 sub update_highlighter {
 	my $self 	= shift;
-	my $x		= shift;
-	my $y		= shift;
-	my $width	= shift;
-	my $height	= shift;
 
-	$self->{_highlighter}->hide;
-	
 	if(defined $self->{_c}{'cw'}{'gdk_window'} && defined $self->{_c}{'cw'}{'window'}){
 
-		#Place window and resize it
-		$self->{_highlighter}->move($x-3, $y-3);
-		$self->{_highlighter}->resize($width+6, $height+6);
-		
 		#and show highlighter window at current cursor position		
 		$self->{_highlighter}->show_all;
-		$self->{_highlighter}->present;
+		$self->{_highlighter}->queue_draw;
 
 		Gtk2::Gdk->keyboard_grab( $self->{_highlighter}->window, 0, Gtk2->get_current_event_time );
 	
@@ -762,12 +761,7 @@ sub select_window {
 	if ( (Gtk2::Gdk->pointer_is_grabbed && ($self->{_c}{'lw'}{'gdk_window'} ne $self->{_c}{'cw'}{'gdk_window'})) || 
 		 (Gtk2::Gdk->pointer_is_grabbed && $self->{_c}{'ws_init'}) ) {
 			 
-		$self->update_highlighter(
-			$self->{_c}{'cw'}{'x'},
-			$self->{_c}{'cw'}{'y'},
-			$self->{_c}{'cw'}{'width'},
-			$self->{_c}{'cw'}{'height'}
-		);
+		$self->update_highlighter();
 		
 		#reset flag
 		$self->{_c}{'ws_init'} = FALSE;
@@ -951,7 +945,7 @@ sub window {
 					$output = $output_new;
 												
 					#respect rounded corners of wm decorations (metacity for example - does not work with compiz currently)	
-					if($self->{_x11}{ext_shape} && $self->{_include_border}){
+					if($self->{_include_border}){
 						my $xid = $self->{_c}{ 'cw' }{ 'gdk_window' }->get_xid;
 						#do not try this for child windows
 						foreach my $win ($self->{_wnck_screen}->get_windows){
@@ -1099,7 +1093,7 @@ sub window {
 		#(metacity for example - does not work with compiz currently)
 		#only if toplevel window was selected
 		if ( ( $self->{_mode} eq "window" || $self->{_mode} eq "tray_window" ||  $self->{_mode} eq "awindow"  || $self->{_mode} eq "tray_awindow" ) ) {
-			if($self->{_x11}{ext_shape} && $self->{_include_border}){
+			if($self->{_include_border}){
 				my $xid = $self->{_c}{ 'cw' }{ 'gdk_window' }->get_xid;
 				#do not try this for child windows
 				foreach my $win ($self->{_wnck_screen}->get_windows){
@@ -1250,7 +1244,9 @@ sub redo_capture {
 				$output = $output_new;
 
 				if($self->{_mode} eq "window" || $self->{_mode} eq "tray_window" || $self->{_mode} eq "awindow" || $self->{_mode} eq "tray_awindow"){
-					$output = $self->get_shape($gxid, $output, $l_cropped, $r_cropped, $t_cropped, $b_cropped);
+					if($self->{_include_border}){
+						$output = $self->get_shape($gxid, $output, $l_cropped, $r_cropped, $t_cropped, $b_cropped);
+					}
 				}
 				
 				#restore window size when autoresizing was used
